Names of the FIADB TREE columns used by default in FIAstemmap
Source:R/data.R
DEFAULT_TREE_COLUMNS.RdDEFAULT_TREE_COLUMNS is a character vector of column names in the FIADB
TREE table that are used to compute various tree- and plot-level derived
variables in FIAstemmap. Note that certain outputs can be
generated without this full set of TREE attributes, but these are the ones
generally needed for all functionality in the package.