Functions to convert between US customary units and SI units for measurements of length and area commonly used with tree data.
Details
ft_to_m(x) converts feet to meters.
m_to_ft(x) converts meters to feet.
in_to_cm(x) converts inches to centimeters.
cm_to_in(x) converts centimeters to inches.
ac_to_ha() converts acres to hectares.
ha_to_ac() converts hectares to acres.
Note
The hectare (ha) is technically a non-SI unit of area that is accepted for use with SI.