Compute fractional tree canopy cover of a subplot/microplot by crown overlay
Source:R/crown_overlay_pct.R
crown_overlay_pct.Rdcrown_overlay_pct() computes the proportion of a circular polygon covered
by a given set of tree crowns modeled as discs and having spatially explicit
stem locations. The sampled area is generally an FIA subplot with radius 24
ft (7.315 m) for trees with diameter >= 5 in. (12.7 cm), or an FIA
microplot with radius 6.8 ft (2.073 m) for trees >= 1 in. (2.54 cm)
but < 5 in. (12.7 cm) diameter (denoted as "saplings"). Stem locations
are specified as distance and azimuth from subplot/microplot center.
Arguments
- tree_list
A data frame containing tree records for a subplot/microplot. Must have columns
DIST(stem distance from subplot/microplot center in the same units assample_radius),AZIMUTH(horizontal angle from subplot/microplot center to the stem location, in the range0:359) andCRWIDTH(tree crown width in the same units assample_radiusandDIST).- sample_radius
A numeric value giving the radius of the circular subplot/microplot.
- digits
Optional integer indicating the number of digits to keep in the return value (defaults to
1, will be passed toround()).