A curated set of linear regression coefficients for predicting crown width from stem diameter of tree species in the conterminous US.
Format
cw_coef
A data frame with 430 rows and 8 columns:
symbolcharacter, USDA PLANTS Database species symbolSPCDinteger, FIA tree species code or-1common_namecharacter, FIA tree species common namesurrogatecharacter, Common name of surrogate species if applicableb0numeric, Regression b0 coefficientb1numeric, Regression b1 coefficientb2numeric, Regression b2 coefficientreferencecharacter, Literature source of the species coefficients (see References)
Toney et al. 2009. A stem-map model for predicting tree canopy cover of Forest Inventory and Analysis (FIA) plots. https://research.fs.usda.gov/treesearch/33381.
Details
The regression equation is of the general form:
where CW is the predicted tree crown diameter in feet, DIA is FIA stem
diameter in inches, and b0, b1, b2 are the regression coefficients.
The quadratic term b2 was not included in the regression models for some
species, and has been assigned 0 in that case for purposes of this lookup
table.
In cases that species-specific equations were not available in the literature, surrogate species were assigned based on subjectively similar tree physiognomy.
References
Bechtold, W.A. 2003. Crown-Diameter Prediction Models for 87 Species of Stand-Grown Trees in the Eastern United States. Southern Journal of Applied Forestry, Vol. 27, No. 4, 269-278.
Bechtold, W.A. 2004. Largest-Crown-Width Prediction Models for 53 Species in the Western United States. Western Journal of Applied Forestry, Vol. 19, No. 4, 245-251.
Gill, S.J., G.S. Biging, E.C. Murphy. 2000. Modeling conifer tree crown radius and estimating canopy cover. Forest Ecology and Management, 126, 405-416.