Skip to contents

An example tree list for an FIA plot in a loblolly pine plantation.

Usage

plantation

Format

plantation

A data frame with 91 rows and 14 columns:

PLT_CN

character, Plot unique identifier

SUBP

integer, Subplot number

TREE

integer, Tree number

AZIMUTH

integer, Horizontal angle from subplot center to the stem location

DIST

numeric, Distance in feet from subplot center to the stem location

STATUSCD

integer, Tree status code: 1 = live, 2 = standing dead

SPCD

integer, FIA tree species code

SPGRPCD

integer, FIA tree species group code

DIA

numeric, Tree diameter at breast height in inches

HT

integer, Tree height in feet

ACTUALHT

integer, Actual height in ft (ACTUALHT < HT indicates a broken top)

CCLCD

integer, Tree crown class code

TPA_UNADJ

numeric, Trees per acre expansion factor

CRWIDTH

numeric, Estimated tree crown width in feet