An example tree list for an FIA plot in a loblolly pine plantation.
Format
plantation
A data frame with 91 rows and 14 columns:
PLT_CNcharacter, Plot unique identifierSUBPinteger, Subplot numberTREEinteger, Tree numberAZIMUTHinteger, Horizontal angle from subplot center to the stem locationDISTnumeric, Distance in feet from subplot center to the stem locationSTATUSCDinteger, Tree status code: 1 = live, 2 = standing deadSPCDinteger, FIA tree species codeSPGRPCDinteger, FIA tree species group codeDIAnumeric, Tree diameter at breast height in inchesHTinteger, Tree height in feetACTUALHTinteger, Actual height in ft (ACTUALHT < HT indicates a broken top)CCLCDinteger, Tree crown class codeTPA_UNADJnumeric, Trees per acre expansion factorCRWIDTHnumeric, Estimated tree crown width in feet